[![PyPI](https://img.shields.io/pypi/v/boardx.svg)](https://pypi.org/project/boardx/) [![GitHub issues](https://img.shields.io/github/issues/xinetzone/d2b)](https://github.com/xinetzone/d2b/issues) [![GitHub forks](https://img.shields.io/github/forks/xinetzone/d2b)](https://github.com/xinetzone/d2b/network) [![GitHub stars](https://img.shields.io/github/stars/xinetzone/d2b)](https://github.com/xinetzone/d2b/stargazers) [![GitHub license](https://img.shields.io/github/license/xinetzone/d2b)](https://github.com/xinetzone/d2b/blob/main/LICENSE) ![repo size](https://img.shields.io/github/repo-size/xinetzone/d2b.svg) [![contributors](https://img.shields.io/github/contributors/xinetzone/d2b.svg)](https://github.com/xinetzone/d2b/graphs/contributors) [![watcher](https://img.shields.io/github/watchers/xinetzone/d2b.svg)](https://github.com/xinetzone/d2b/watchers) [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/xinetzone/d2b/main) [![Downloads](https://pepy.tech/badge/boardx/week)](https://pepy.tech/project/boardx) [![Downloads](https://pepy.tech/badge/boardx)](https://pepy.tech/project/boardx) [![Documentation Status](https://readthedocs.org/projects/boardx/badge/?version=latest)](https://boardx.readthedocs.io/zh/latest/?badge=latest)

Discover and create anything interesting!

## PyPI

Provide PyPI support:

```sh
pip install boardx
```

For documentation see [d2b](https://xinetzone.github.io/d2b).
